@@ -6,24 +6,22 @@
  */
 
 #include "unitcategory.h"
-#include "unitcategory_p.h"
 #include "unit_p.h"
+#include "unitcategory_p.h"
 
-#include <KI18n/klocalizedstring.h>
-
+#include <KLocalizedString>
 
 namespace KUnitConversion
 {
-
 UnitCategoryPrivate::UnitCategoryPrivate()
     : m_id(InvalidCategory)
 {
 }
 
 UnitCategoryPrivate::UnitCategoryPrivate(CategoryId id, const QString &name, const QString &description)
-    : m_id(id),
-      m_name(name),
-      m_description(description)
+    : m_id(id)
+    , m_name(name)
+    , m_description(description)
 {
 }
 
@@ -79,18 +77,20 @@ UnitCategory &UnitCategory::operator=(const UnitCategory &other)
 
 bool UnitCategory::operator==(const UnitCategory &other) const
 {
-    if (d && other.d)
+    if (d && other.d) {
         return (*d == *other.d);
-    else
+    } else {
         return (d == other.d);
+    }
 }
 
 bool UnitCategory::operator!=(const UnitCategory &other) const
 {
-    if (d && other.d)
+    if (d && other.d) {
         return (*d != *other.d);
-    else
+    } else {
         return (d != other.d);
+    }
 }
 
 bool UnitCategory::isNull() const
@@ -100,36 +100,41 @@ bool UnitCategory::isNull() const
 
 CategoryId UnitCategory::id() const
 {
-    if (d)
+    if (d) {
         return d->m_id;
+    }
     return InvalidCategory;
 }
 
 QList<Unit> UnitCategory::units() const
 {
-    if (d)
+    if (d) {
         return d->m_units;
+    }
     return QList<Unit>();
 }
 
 QList<Unit> UnitCategory::mostCommonUnits() const
 {
-    if (d)
+    if (d) {
         return d->m_mostCommonUnits;
+    }
     return QList<Unit>();
 }
 
 QStringList UnitCategory::allUnits() const
 {
-    if (d)
+    if (d) {
         return d->m_unitMap.keys();
+    }
     return QStringList();
 }
 
 bool UnitCategory::hasUnit(const QString &unit) const
 {
-    if (d)
+    if (d) {
         return d->m_unitMap.contains(unit);
+    }
     return false;
 }
 
@@ -160,8 +165,9 @@ Value UnitCategory::convert(const Value &value, const Unit &toUnit)
 
 Unit UnitCategory::unit(const QString &s) const
 {
-    if (d)
+    if (d) {
         return d->m_unitMap.value(s);
+    }
     return Unit();
 }
 
@@ -175,51 +181,83 @@ Unit UnitCategory::unit(UnitId unitId) const
 
 QString UnitCategory::name() const
 {
-    if (d)
+    if (d) {
         return d->m_name;
+    }
     return QString();
 }
 
 Unit UnitCategory::defaultUnit() const
 {
-    if (d)
+    if (d) {
         return d->m_defaultUnit;
+    }
     return Unit();
 }
 
 QString UnitCategory::description() const
 {
-    if (d)
+    if (d) {
         return d->m_description;
+    }
     return QString();
 }
 
 void UnitCategory::addDefaultUnit(const Unit &unit)
 {
     if (d) {
-        addCommonUnit(unit);
-        d->m_defaultUnit = unit;
+        d->addDefaultUnit(unit);
     }
 }
 
+void UnitCategoryPrivate::addDefaultUnit(const Unit &unit)
+{
+    addCommonUnit(unit);
+    m_defaultUnit = unit;
+}
+
 void UnitCategory::addCommonUnit(const Unit &unit)
 {
     if (d) {
-        addUnit(unit);
-        d->m_mostCommonUnits.append(unit);
+        d->addCommonUnit(unit);
     }
 }
 
+void UnitCategoryPrivate::addCommonUnit(const Unit &unit)
+{
+    addUnit(unit);
+    m_mostCommonUnits.append(unit);
+}
+
 void UnitCategory::addUnit(const Unit &unit)
 {
     if (d) {
-        unit.d->m_category = *this;
-        const QStringList list = unit.d->m_matchString.split(QLatin1Char(';'));
-        for (const QString &name : list)
-            d->m_unitMap[name] = unit;
-        d->m_idMap[unit.id()] = unit;
-        d->m_units.append(unit);
+        d->addUnit(unit);
     }
 }
 
+void UnitCategoryPrivate::addUnit(const Unit &unit)
+{
+    // ### this is emulating a weak_ptr to break a reference cycle between Unit and UnitCategory
+    // ### even without that, this is slicing the polymorphic part of UnitCategory
+    // this only works by chance as apart from the ctors those parts contain no logic or data it seems
+    unit.d->m_category = this;
+    const QStringList list = unit.d->m_matchString.split(QLatin1Char(';'));
+    for (const QString &name : list) {
+        m_unitMap[name] = unit;
+    }
+    m_idMap[unit.id()] = unit;
+    m_units.append(unit);
+}
+
+bool UnitCategory::hasOnlineConversionTable() const
+{
+    return d->hasOnlineConversionTable();
+}
+
+void UnitCategory::syncConversionTable(std::chrono::seconds updateSkipPeriod)
+{
+    d->syncConversionTable(updateSkipPeriod);
+}
+
 }
