@@ -8,16 +8,18 @@
 #include "unit_p.h"
 #include "volume_p.h"
 
-#include <KI18n/klocalizedstring.h>
+#include <KLocalizedString>
 
 namespace KUnitConversion
 {
-Volume::Volume()
-    : CustomCategory(VolumeCategory, i18n("Volume"), i18n("Volume"))
+
+UnitCategory Volume::makeCategory()
 {
+    auto c = UnitCategoryPrivate::makeCategory(VolumeCategory, i18n("Volume"), i18n("Volume"));
+    auto d = UnitCategoryPrivate::get(c);
     KLocalizedString symbolString = ki18nc("%1 value, %2 unit symbol (volume)", "%1 %2");
 
-    addUnit(CustomUnit(VolumeCategory,
+    d->addUnit(UnitPrivate::makeUnit(VolumeCategory,
                        CubicYottameter,
                        1e+72,
                        i18nc("volume unit symbol", "Ym³"),
@@ -27,7 +29,7 @@ Volume::Volume()
                        symbolString,
                        ki18ncp("amount in units (integer)", "%1 cubic yottameter", "%1 cubic yottameters")));
 
-    addUnit(CustomUnit(VolumeCategory,
+    d->addUnit(UnitPrivate::makeUnit(VolumeCategory,
                        CubicZettameter,
                        1e+63,
                        i18nc("volume unit symbol", "Zm³"),
@@ -37,7 +39,7 @@ Volume::Volume()
                        ki18nc("amount in units (real)", "%1 cubic zettameters"),
                        ki18ncp("amount in units (integer)", "%1 cubic zettameter", "%1 cubic zettameters")));
 
-    addUnit(CustomUnit(VolumeCategory,
+    d->addUnit(UnitPrivate::makeUnit(VolumeCategory,
                        CubicExameter,
                        1e+54,
                        i18nc("volume unit symbol", "Em³"),
@@ -47,7 +49,7 @@ Volume::Volume()
                        ki18nc("amount in units (real)", "%1 cubic exameters"),
                        ki18ncp("amount in units (integer)", "%1 cubic exameter", "%1 cubic exameters")));
 
-    addUnit(CustomUnit(VolumeCategory,
+    d->addUnit(UnitPrivate::makeUnit(VolumeCategory,
                        CubicPetameter,
                        1e+45,
                        i18nc("volume unit symbol", "Pm³"),
@@ -57,7 +59,7 @@ Volume::Volume()
                        ki18nc("amount in units (real)", "%1 cubic petameters"),
                        ki18ncp("amount in units (integer)", "%1 cubic petameter", "%1 cubic petameters")));
 
-    addUnit(CustomUnit(VolumeCategory,
+    d->addUnit(UnitPrivate::makeUnit(VolumeCategory,
                        CubicTerameter,
                        1e+36,
                        i18nc("volume unit symbol", "Tm³"),
@@ -67,7 +69,7 @@ Volume::Volume()
                        ki18nc("amount in units (real)", "%1 cubic terameters"),
                        ki18ncp("amount in units (integer)", "%1 cubic terameter", "%1 cubic terameters")));
 
-    addUnit(CustomUnit(VolumeCategory,
+    d->addUnit(UnitPrivate::makeUnit(VolumeCategory,
                        CubicGigameter,
                        1e+27,
                        i18nc("volume unit symbol", "Gm³"),
@@ -77,7 +79,7 @@ Volume::Volume()
                        ki18nc("amount in units (real)", "%1 cubic gigameters"),
                        ki18ncp("amount in units (integer)", "%1 cubic gigameter", "%1 cubic gigameters")));
 
-    addUnit(CustomUnit(VolumeCategory,
+    d->addUnit(UnitPrivate::makeUnit(VolumeCategory,
                        CubicMegameter,
                        1e+18,
                        i18nc("volume unit symbol", "Mm³"),
@@ -87,7 +89,7 @@ Volume::Volume()
                        ki18nc("amount in units (real)", "%1 cubic megameters"),
                        ki18ncp("amount in units (integer)", "%1 cubic megameter", "%1 cubic megameters")));
 
-    addUnit(CustomUnit(VolumeCategory,
+    d->addUnit(UnitPrivate::makeUnit(VolumeCategory,
                        CubicKilometer,
                        1e+09,
                        i18nc("volume unit symbol", "km³"),
@@ -97,7 +99,7 @@ Volume::Volume()
                        ki18nc("amount in units (real)", "%1 cubic kilometers"),
                        ki18ncp("amount in units (integer)", "%1 cubic kilometer", "%1 cubic kilometers")));
 
-    addUnit(CustomUnit(VolumeCategory,
+    d->addUnit(UnitPrivate::makeUnit(VolumeCategory,
                        CubicHectometer,
                        1e+06,
                        i18nc("volume unit symbol", "hm³"),
@@ -107,7 +109,7 @@ Volume::Volume()
                        ki18nc("amount in units (real)", "%1 cubic hectometers"),
                        ki18ncp("amount in units (integer)", "%1 cubic hectometer", "%1 cubic hectometers")));
 
-    addUnit(CustomUnit(VolumeCategory,
+    d->addUnit(UnitPrivate::makeUnit(VolumeCategory,
                        CubicDecameter,
                        1000,
                        i18nc("volume unit symbol", "dam³"),
@@ -117,7 +119,7 @@ Volume::Volume()
                        ki18nc("amount in units (real)", "%1 cubic decameters"),
                        ki18ncp("amount in units (integer)", "%1 cubic decameter", "%1 cubic decameters")));
 
-    addCommonUnit(CustomUnit(VolumeCategory,
+    d->addCommonUnit(UnitPrivate::makeUnit(VolumeCategory,
                              CubicMeter,
                              1,
                              i18nc("volume unit symbol", "m³"),
@@ -127,7 +129,7 @@ Volume::Volume()
                              ki18nc("amount in units (real)", "%1 cubic meters"),
                              ki18ncp("amount in units (integer)", "%1 cubic meter", "%1 cubic meters")));
 
-    addUnit(CustomUnit(VolumeCategory,
+    d->addUnit(UnitPrivate::makeUnit(VolumeCategory,
                        CubicDecimeter,
                        0.001,
                        i18nc("volume unit symbol", "dm³"),
@@ -137,7 +139,7 @@ Volume::Volume()
                        ki18nc("amount in units (real)", "%1 cubic decimeters"),
                        ki18ncp("amount in units (integer)", "%1 cubic decimeter", "%1 cubic decimeters")));
 
-    addUnit(CustomUnit(VolumeCategory,
+    d->addUnit(UnitPrivate::makeUnit(VolumeCategory,
                        CubicCentimeter,
                        1e-06,
                        i18nc("volume unit symbol", "cm³"),
@@ -147,7 +149,7 @@ Volume::Volume()
                        ki18nc("amount in units (real)", "%1 cubic centimeters"),
                        ki18ncp("amount in units (integer)", "%1 cubic centimeter", "%1 cubic centimeters")));
 
-    addUnit(CustomUnit(VolumeCategory,
+    d->addUnit(UnitPrivate::makeUnit(VolumeCategory,
                        CubicMillimeter,
                        1e-09,
                        i18nc("volume unit symbol", "mm³"),
@@ -157,7 +159,7 @@ Volume::Volume()
                        ki18nc("amount in units (real)", "%1 cubic millimeters"),
                        ki18ncp("amount in units (integer)", "%1 cubic millimeter", "%1 cubic millimeters")));
 
-    addUnit(CustomUnit(VolumeCategory,
+    d->addUnit(UnitPrivate::makeUnit(VolumeCategory,
                        CubicMicrometer,
                        1e-18,
                        i18nc("volume unit symbol", "µm³"),
@@ -167,7 +169,7 @@ Volume::Volume()
                        ki18nc("amount in units (real)", "%1 cubic micrometers"),
                        ki18ncp("amount in units (integer)", "%1 cubic micrometer", "%1 cubic micrometers")));
 
-    addUnit(CustomUnit(VolumeCategory,
+    d->addUnit(UnitPrivate::makeUnit(VolumeCategory,
                        CubicNanometer,
                        1e-27,
                        i18nc("volume unit symbol", "nm³"),
@@ -177,7 +179,7 @@ Volume::Volume()
                        ki18nc("amount in units (real)", "%1 cubic nanometers"),
                        ki18ncp("amount in units (integer)", "%1 cubic nanometer", "%1 cubic nanometers")));
 
-    addUnit(CustomUnit(VolumeCategory,
+    d->addUnit(UnitPrivate::makeUnit(VolumeCategory,
                        CubicPicometer,
                        1e-36,
                        i18nc("volume unit symbol", "pm³"),
@@ -187,7 +189,7 @@ Volume::Volume()
                        ki18nc("amount in units (real)", "%1 cubic picometers"),
                        ki18ncp("amount in units (integer)", "%1 cubic picometer", "%1 cubic picometers")));
 
-    addUnit(CustomUnit(VolumeCategory,
+    d->addUnit(UnitPrivate::makeUnit(VolumeCategory,
                        CubicFemtometer,
                        1e-45,
                        i18nc("volume unit symbol", "fm³"),
@@ -197,7 +199,7 @@ Volume::Volume()
                        ki18nc("amount in units (real)", "%1 cubic femtometers"),
                        ki18ncp("amount in units (integer)", "%1 cubic femtometer", "%1 cubic femtometers")));
 
-    addUnit(CustomUnit(VolumeCategory,
+    d->addUnit(UnitPrivate::makeUnit(VolumeCategory,
                        CubicAttometer,
                        1e-54,
                        i18nc("volume unit symbol", "am³"),
@@ -207,7 +209,7 @@ Volume::Volume()
                        ki18nc("amount in units (real)", "%1 cubic attometers"),
                        ki18ncp("amount in units (integer)", "%1 cubic attometer", "%1 cubic attometers")));
 
-    addUnit(CustomUnit(VolumeCategory,
+    d->addUnit(UnitPrivate::makeUnit(VolumeCategory,
                        CubicZeptometer,
                        1e-63,
                        i18nc("volume unit symbol", "zm³"),
@@ -217,7 +219,7 @@ Volume::Volume()
                        ki18nc("amount in units (real)", "%1 cubic zeptometers"),
                        ki18ncp("amount in units (integer)", "%1 cubic zeptometer", "%1 cubic zeptometers")));
 
-    addUnit(CustomUnit(VolumeCategory,
+    d->addUnit(UnitPrivate::makeUnit(VolumeCategory,
                        CubicYoctometer,
                        1e-72,
                        i18nc("volume unit symbol", "ym³"),
@@ -227,7 +229,7 @@ Volume::Volume()
                        ki18nc("amount in units (real)", "%1 cubic yoctometers"),
                        ki18ncp("amount in units (integer)", "%1 cubic yoctometer", "%1 cubic yoctometers")));
 
-    addUnit(CustomUnit(VolumeCategory,
+    d->addUnit(UnitPrivate::makeUnit(VolumeCategory,
                        Yottaliter,
                        1e+21,
                        i18nc("volume unit symbol", "Yl"),
@@ -237,7 +239,7 @@ Volume::Volume()
                        ki18nc("amount in units (real)", "%1 yottaliters"),
                        ki18ncp("amount in units (integer)", "%1 yottaliter", "%1 yottaliters")));
 
-    addUnit(CustomUnit(VolumeCategory,
+    d->addUnit(UnitPrivate::makeUnit(VolumeCategory,
                        Zettaliter,
                        1e+18,
                        i18nc("volume unit symbol", "Zl"),
@@ -247,7 +249,7 @@ Volume::Volume()
                        ki18nc("amount in units (real)", "%1 zettaliters"),
                        ki18ncp("amount in units (integer)", "%1 zettaliter", "%1 zettaliters")));
 
-    addUnit(CustomUnit(VolumeCategory,
+    d->addUnit(UnitPrivate::makeUnit(VolumeCategory,
                        Exaliter,
                        1e+15,
                        i18nc("volume unit symbol", "El"),
@@ -257,7 +259,7 @@ Volume::Volume()
                        ki18nc("amount in units (real)", "%1 exaliters"),
                        ki18ncp("amount in units (integer)", "%1 exaliter", "%1 exaliters")));
 
-    addUnit(CustomUnit(VolumeCategory,
+    d->addUnit(UnitPrivate::makeUnit(VolumeCategory,
                        Petaliter,
                        1e+12,
                        i18nc("volume unit symbol", "Pl"),
@@ -267,7 +269,7 @@ Volume::Volume()
                        ki18nc("amount in units (real)", "%1 petaliters"),
                        ki18ncp("amount in units (integer)", "%1 petaliter", "%1 petaliters")));
 
-    addUnit(CustomUnit(VolumeCategory,
+    d->addUnit(UnitPrivate::makeUnit(VolumeCategory,
                        Teraliter,
                        1e+09,
                        i18nc("volume unit symbol", "Tl"),
@@ -277,7 +279,7 @@ Volume::Volume()
                        ki18nc("amount in units (real)", "%1 teraliters"),
                        ki18ncp("amount in units (integer)", "%1 teraliter", "%1 teraliters")));
 
-    addUnit(CustomUnit(VolumeCategory,
+    d->addUnit(UnitPrivate::makeUnit(VolumeCategory,
                        Gigaliter,
                        1e+06,
                        i18nc("volume unit symbol", "Gl"),
@@ -287,7 +289,7 @@ Volume::Volume()
                        ki18nc("amount in units (real)", "%1 gigaliters"),
                        ki18ncp("amount in units (integer)", "%1 gigaliter", "%1 gigaliters")));
 
-    addUnit(CustomUnit(VolumeCategory,
+    d->addUnit(UnitPrivate::makeUnit(VolumeCategory,
                        Megaliter,
                        1000,
                        i18nc("volume unit symbol", "Ml"),
@@ -297,7 +299,7 @@ Volume::Volume()
                        ki18nc("amount in units (real)", "%1 megaliters"),
                        ki18ncp("amount in units (integer)", "%1 megaliter", "%1 megaliters")));
 
-    addDefaultUnit(CustomUnit(VolumeCategory,
+    d->addDefaultUnit(UnitPrivate::makeUnit(VolumeCategory,
                               Kiloliter,
                               1,
                               i18nc("volume unit symbol", "kl"),
@@ -307,7 +309,7 @@ Volume::Volume()
                               ki18nc("amount in units (real)", "%1 kiloliters"),
                               ki18ncp("amount in units (integer)", "%1 kiloliter", "%1 kiloliters")));
 
-    addUnit(CustomUnit(VolumeCategory,
+    d->addUnit(UnitPrivate::makeUnit(VolumeCategory,
                        Hectoliter,
                        0.1,
                        i18nc("volume unit symbol", "hl"),
@@ -317,7 +319,7 @@ Volume::Volume()
                        ki18nc("amount in units (real)", "%1 hectoliters"),
                        ki18ncp("amount in units (integer)", "%1 hectoliter", "%1 hectoliters")));
 
-    addUnit(CustomUnit(VolumeCategory,
+    d->addUnit(UnitPrivate::makeUnit(VolumeCategory,
                        Decaliter,
                        0.01,
                        i18nc("volume unit symbol", "dal"),
@@ -327,7 +329,7 @@ Volume::Volume()
                        ki18nc("amount in units (real)", "%1 decaliters"),
                        ki18ncp("amount in units (integer)", "%1 decaliter", "%1 decaliters")));
 
-    addCommonUnit(CustomUnit(VolumeCategory,
+    d->addCommonUnit(UnitPrivate::makeUnit(VolumeCategory,
                              Liter,
                              0.001,
                              i18nc("volume unit symbol", "l"),
@@ -337,7 +339,7 @@ Volume::Volume()
                              ki18nc("amount in units (real)", "%1 liters"),
                              ki18ncp("amount in units (integer)", "%1 liter", "%1 liters")));
 
-    addUnit(CustomUnit(VolumeCategory,
+    d->addUnit(UnitPrivate::makeUnit(VolumeCategory,
                        Deciliter,
                        0.0001,
                        i18nc("volume unit symbol", "dl"),
@@ -347,7 +349,7 @@ Volume::Volume()
                        ki18nc("amount in units (real)", "%1 deciliters"),
                        ki18ncp("amount in units (integer)", "%1 deciliter", "%1 deciliters")));
 
-    addUnit(CustomUnit(VolumeCategory,
+    d->addUnit(UnitPrivate::makeUnit(VolumeCategory,
                        Centiliter,
                        1e-05,
                        i18nc("volume unit symbol", "cl"),
@@ -357,7 +359,7 @@ Volume::Volume()
                        ki18nc("amount in units (real)", "%1 centiliters"),
                        ki18ncp("amount in units (integer)", "%1 centiliter", "%1 centiliters")));
 
-    addCommonUnit(CustomUnit(VolumeCategory,
+    d->addCommonUnit(UnitPrivate::makeUnit(VolumeCategory,
                              Milliliter,
                              1e-06,
                              i18nc("volume unit symbol", "ml"),
@@ -367,7 +369,7 @@ Volume::Volume()
                              ki18nc("amount in units (real)", "%1 milliliters"),
                              ki18ncp("amount in units (integer)", "%1 milliliter", "%1 milliliters")));
 
-    addUnit(CustomUnit(VolumeCategory,
+    d->addUnit(UnitPrivate::makeUnit(VolumeCategory,
                        Microliter,
                        1e-09,
                        i18nc("volume unit symbol", "µl"),
@@ -377,7 +379,7 @@ Volume::Volume()
                        ki18nc("amount in units (real)", "%1 microliters"),
                        ki18ncp("amount in units (integer)", "%1 microliter", "%1 microliters")));
 
-    addUnit(CustomUnit(VolumeCategory,
+    d->addUnit(UnitPrivate::makeUnit(VolumeCategory,
                        Nanoliter,
                        1e-12,
                        i18nc("volume unit symbol", "nl"),
@@ -387,7 +389,7 @@ Volume::Volume()
                        ki18nc("amount in units (real)", "%1 nanoliters"),
                        ki18ncp("amount in units (integer)", "%1 nanoliter", "%1 nanoliters")));
 
-    addUnit(CustomUnit(VolumeCategory,
+    d->addUnit(UnitPrivate::makeUnit(VolumeCategory,
                        Picoliter,
                        1e-15,
                        i18nc("volume unit symbol", "pl"),
@@ -397,7 +399,7 @@ Volume::Volume()
                        ki18nc("amount in units (real)", "%1 picoliters"),
                        ki18ncp("amount in units (integer)", "%1 picoliter", "%1 picoliters")));
 
-    addUnit(CustomUnit(VolumeCategory,
+    d->addUnit(UnitPrivate::makeUnit(VolumeCategory,
                        Femtoliter,
                        1e-18,
                        i18nc("volume unit symbol", "fl"),
@@ -407,7 +409,7 @@ Volume::Volume()
                        ki18nc("amount in units (real)", "%1 femtoliters"),
                        ki18ncp("amount in units (integer)", "%1 femtoliter", "%1 femtoliters")));
 
-    addUnit(CustomUnit(VolumeCategory,
+    d->addUnit(UnitPrivate::makeUnit(VolumeCategory,
                        Attoliter,
                        1e-21,
                        i18nc("volume unit symbol", "al"),
@@ -417,7 +419,7 @@ Volume::Volume()
                        ki18nc("amount in units (real)", "%1 attoliters"),
                        ki18ncp("amount in units (integer)", "%1 attoliter", "%1 attoliters")));
 
-    addUnit(CustomUnit(VolumeCategory,
+    d->addUnit(UnitPrivate::makeUnit(VolumeCategory,
                        Zeptoliter,
                        1e-24,
                        i18nc("volume unit symbol", "zl"),
@@ -427,7 +429,7 @@ Volume::Volume()
                        ki18nc("amount in units (real)", "%1 zeptoliters"),
                        ki18ncp("amount in units (integer)", "%1 zeptoliter", "%1 zeptoliters")));
 
-    addUnit(CustomUnit(VolumeCategory,
+    d->addUnit(UnitPrivate::makeUnit(VolumeCategory,
                        Yoctoliter,
                        1e-27,
                        i18nc("volume unit symbol", "yl"),
@@ -437,7 +439,7 @@ Volume::Volume()
                        ki18nc("amount in units (real)", "%1 yoctoliters"),
                        ki18ncp("amount in units (integer)", "%1 yoctoliter", "%1 yoctoliters")));
 
-    addUnit(CustomUnit(VolumeCategory,
+    d->addUnit(UnitPrivate::makeUnit(VolumeCategory,
                        CubicFoot,
                        0.0283168,
                        i18nc("volume unit symbol", "ft³"),
@@ -447,7 +449,7 @@ Volume::Volume()
                        ki18nc("amount in units (real)", "%1 cubic feet"),
                        ki18ncp("amount in units (integer)", "%1 cubic foot", "%1 cubic feet")));
 
-    addUnit(CustomUnit(VolumeCategory,
+    d->addUnit(UnitPrivate::makeUnit(VolumeCategory,
                        CubicInch,
                        1.63871e-05,
                        i18nc("volume unit symbol", "in³"),
@@ -457,7 +459,7 @@ Volume::Volume()
                        ki18nc("amount in units (real)", "%1 cubic inches"),
                        ki18ncp("amount in units (integer)", "%1 cubic inch", "%1 cubic inches")));
 
-    addUnit(CustomUnit(VolumeCategory,
+    d->addUnit(UnitPrivate::makeUnit(VolumeCategory,
                        CubicMile,
                        4.16818e+09,
                        i18nc("volume unit symbol", "mi³"),
@@ -467,7 +469,7 @@ Volume::Volume()
                        ki18nc("amount in units (real)", "%1 cubic miles"),
                        ki18ncp("amount in units (integer)", "%1 cubic mile", "%1 cubic miles")));
 
-    addCommonUnit(CustomUnit(VolumeCategory,
+    d->addCommonUnit(UnitPrivate::makeUnit(VolumeCategory,
                              FluidOunce,
                              2.95735e-05,
                              i18nc("volume unit symbol", "fl.oz."),
@@ -477,7 +479,7 @@ Volume::Volume()
                              ki18nc("amount in units (real)", "%1 fluid ounces"),
                              ki18ncp("amount in units (integer)", "%1 fluid ounce", "%1 fluid ounces")));
 
-    addCommonUnit(CustomUnit(VolumeCategory,
+    d->addCommonUnit(UnitPrivate::makeUnit(VolumeCategory,
                              Cup,
                              0.000236588,
                              i18nc("volume unit symbol", "cp"),
@@ -487,7 +489,27 @@ Volume::Volume()
                              ki18nc("amount in units (real)", "%1 cups"),
                              ki18ncp("amount in units (integer)", "%1 cup", "%1 cups")));
 
-    addCommonUnit(CustomUnit(VolumeCategory,
+    d->addCommonUnit(UnitPrivate::makeUnit(VolumeCategory,
+                            Teaspoon,
+                            0.000005, // FDA standard 5ml
+                            i18nc("volume unit symbol", "tsp"),
+                            i18nc("unit description in lists", "teaspoon"),
+                            i18nc("unit synonyms for matching user input", "teaspoons;tsps"),
+                            symbolString,
+                            ki18nc("amount in units (real)", "%1 teaspoons"),
+                            ki18ncp("amount in units (integer)", "%1 teaspoon", "%1 teaspoons")));
+
+    d->addCommonUnit(UnitPrivate::makeUnit(VolumeCategory,
+                            Tablespoon,
+                            0.000015, // FDA standard 15ml
+                            i18nc("volume unit symbol", "tbsp"),
+                            i18nc("unit description in lists", "tablespoon"),
+                            i18nc("unit synonyms for matching user input", "tablespoons;tbsps"),
+                            symbolString,
+                            ki18nc("amount in units (real)", "%1 tablespoons"),
+                            ki18ncp("amount in units (integer)", "%1 tablespoon", "%1 tablespoons")));
+
+    d->addCommonUnit(UnitPrivate::makeUnit(VolumeCategory,
                              GallonUS,
                              0.00378541,
                              i18nc("volume unit symbol", "gal"),
@@ -497,7 +519,7 @@ Volume::Volume()
                              ki18nc("amount in units (real)", "%1 gallons (U.S. liquid)"),
                              ki18ncp("amount in units (integer)", "%1 gallon (U.S. liquid)", "%1 gallons (U.S. liquid)")));
 
-    addUnit(CustomUnit(VolumeCategory,
+    d->addUnit(UnitPrivate::makeUnit(VolumeCategory,
                        GallonImperial,
                        0.00454609,
                        i18nc("volume unit symbol", "imp gal"),
@@ -508,7 +530,7 @@ Volume::Volume()
                        ki18nc("amount in units (real)", "%1 gallons (imperial)"),
                        ki18ncp("amount in units (integer)", "%1 gallon (imperial)", "%1 gallons (imperial)")));
 
-    addCommonUnit(CustomUnit(VolumeCategory,
+    d->addCommonUnit(UnitPrivate::makeUnit(VolumeCategory,
                              PintImperial,
                              0.000568261,
                              i18nc("volume unit symbol", "pt"),
@@ -518,7 +540,7 @@ Volume::Volume()
                              ki18nc("amount in units (real)", "%1 pints (imperial)"),
                              ki18ncp("amount in units (integer)", "%1 pint (imperial)", "%1 pints (imperial)")));
 
-    addUnit(CustomUnit(VolumeCategory,
+    d->addUnit(UnitPrivate::makeUnit(VolumeCategory,
                        PintUS,
                        0.000473176,
                        i18nc("volume unit symbol", "US pt"),
@@ -528,7 +550,7 @@ Volume::Volume()
                        ki18nc("amount in units (real)", "%1 pints (U.S. liquid)"),
                        ki18ncp("amount in units (integer)", "%1 pint (U.S. liquid)", "%1 pints (U.S. liquid)")));
 
-    addUnit(CustomUnit(VolumeCategory,
+    d->addUnit(UnitPrivate::makeUnit(VolumeCategory,
                        OilBarrel,
                        0.158987294,
                        i18nc("volume unit symbol", "bbl"),
@@ -537,6 +559,8 @@ Volume::Volume()
                        symbolString,
                        ki18nc("amount in units (real)", "%1 oil barrels"),
                        ki18ncp("amount in units (integer)", "%1 oil barrel", "%1 oil barrels")));
+
+    return c;
 }
 
 } // KUnitConversion namespace
